=======
 spsim
=======

``spsim`` is a Python module that implements a spelling similarity measure
for identifying cognates across languages, taking into account spelling
differences that are characteristic of each language pair, as described
in [Gomes2011]_.


.. [Gomes2011] Measuring Spelling Similarity for Cognate Identification,
    Luís Gomes and Gabriel Pereira Lopes
    in *Progress in Artificial Intelligence, 15th Portuguese Conference in
    Artificial Intelligence, EPIA 2011, Lisboa, Portugal, October 2011*,
    http://www.springerlink.com/content/gtl56j3l06906020/
